# json-data-type-transcompiler

![pytest.yml](https://github.com/joeyshi12/json-data-type-transcompiler/actions/workflows/pytest.yml/badge.svg)

A transcompiler from JSON to a programming language by inferring types from the JSON values.

A web interface for using this library is provided at <a href="https://devtools.joeyshi.xyz">devtools.joeyshi.xyz</a>
